package com.link.core.util;

import com.alibaba.fastjson.JSONObject;
import com.google.gson.Gson;
import com.link.base.logs.model.HttpLog;
import com.link.core.cllog.LCLogger;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;
import java.net.HttpURLConnection;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.net.URLEncoder;
import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import javax.net.ssl.KeyManager;
import javax.net.ssl.SSLContext;
import javax.net.ssl.TrustManager;
import javax.net.ssl.X509TrustManager;
import org.apache.http.HttpResponse;
import org.apache.http.NameValuePair;
import org.apache.http.client.HttpClient;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.HttpDelete;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.client.methods.HttpPut;
import org.apache.http.conn.ClientConnectionManager;
import org.apache.http.conn.scheme.Scheme;
import org.apache.http.conn.scheme.SchemeRegistry;
import org.apache.http.conn.ssl.SSLSocketFactory;
import org.apache.http.entity.ByteArrayEntity;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

public class HttpUtils {
   private static final Logger logger = LogManager.getLogger(HttpUtils.class);

   public static HttpResponse doGet(String host, String path, String method, Map<String, String> headers, Map<String, String> querys) throws Exception {
      HttpClient httpClient = wrapClient(host);
      HttpLog httpLog = new HttpLog();
      HttpGet request = new HttpGet(buildUrl(host, path, querys, httpLog));
      Iterator var8 = headers.entrySet().iterator();

      while(var8.hasNext()) {
         Map.Entry<String, String> e = (Map.Entry)var8.next();
         request.addHeader((String)e.getKey(), (String)e.getValue());
      }

      httpLog.setReqTime(System.currentTimeMillis());
      HttpResponse response = httpClient.execute(request);
      httpLog.setRespTime(System.currentTimeMillis());
      httpLog.setHttpStatus(response.getStatusLine().getStatusCode());

      try {
         String resultStr = EntityUtils.toString(response.getEntity());
         httpLog.setRespBody(resultStr);
      } catch (Exception var18) {
         Exception e = var18;
         httpLog.setErrorMsg(e.getMessage());
      } finally {
         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var17) {
            Exception e3 = var17;
            LCLogger.withException(e3);
         }

      }

      return response;
   }

   public static HttpResponse doPost(String host, String path, String method, Map<String, String> headers, Map<String, String> querys, Map<String, String> bodys) throws Exception {
      HttpLog httpLog = new HttpLog();
      HttpPost request = new HttpPost(buildUrl(host, path, querys, httpLog));
      if (bodys != null && !bodys.isEmpty()) {
         Gson gson = new Gson();
         String reqParams = httpLog.getReqParams();
         if (StringUtils.isNotBlank(reqParams)) {
            reqParams = reqParams + "==" + gson.toJson(bodys);
         } else {
            reqParams = gson.toJson(bodys);
         }

         httpLog.setReqParams(reqParams);
      }

      Iterator var21 = headers.entrySet().iterator();

      while(var21.hasNext()) {
         Map.Entry<String, String> e = (Map.Entry)var21.next();
         request.addHeader((String)e.getKey(), (String)e.getValue());
      }

      String resultStr;
      if (bodys != null) {
         List<NameValuePair> nameValuePairList = new ArrayList();
         Iterator var26 = bodys.keySet().iterator();

         while(var26.hasNext()) {
            resultStr = (String)var26.next();
            nameValuePairList.add(new BasicNameValuePair(resultStr, (String)bodys.get(resultStr)));
         }

         UrlEncodedFormEntity formEntity = new UrlEncodedFormEntity(nameValuePairList, "utf-8");
         formEntity.setContentType("application/x-www-form-urlencoded; charset=UTF-8");
         request.setEntity(formEntity);
      }

      httpLog.setReqTime(System.currentTimeMillis());
      HttpClient httpClient = wrapClient(host);
      HttpResponse httpResponse = httpClient.execute(request);
      httpLog.setRespTime(System.currentTimeMillis());
      httpLog.setHttpStatus(httpResponse.getStatusLine().getStatusCode());

      try {
         resultStr = EntityUtils.toString(httpResponse.getEntity());
         httpLog.setRespBody(resultStr);
      } catch (Exception var19) {
         Exception e = var19;
         httpLog.setErrorMsg(e.getMessage());
      } finally {
         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var18) {
            Exception e3 = var18;
            LCLogger.withException(e3);
         }

      }

      return httpResponse;
   }

   public static HttpResponse doPost(String host, String path, String method, Map<String, String> headers, Map<String, String> querys, String body) throws Exception {
      HttpLog httpLog = new HttpLog();
      HttpPost request = new HttpPost(buildUrl(host, path, querys, httpLog));
      if (body != null && !body.isEmpty()) {
         Gson gson = new Gson();
         String reqParams = httpLog.getReqParams();
         if (StringUtils.isNotBlank(reqParams)) {
            reqParams = reqParams + "==" + gson.toJson(body);
         } else {
            reqParams = gson.toJson(body);
         }

         httpLog.setReqParams(reqParams);
      }

      Iterator var21 = headers.entrySet().iterator();

      while(var21.hasNext()) {
         Map.Entry<String, String> e = (Map.Entry)var21.next();
         request.addHeader((String)e.getKey(), (String)e.getValue());
      }

      if (StringUtils.isNotBlank(body)) {
         request.setEntity(new StringEntity(body, "utf-8"));
      }

      httpLog.setReqTime(System.currentTimeMillis());
      HttpClient httpClient = wrapClient(host);
      HttpResponse httpResponse = httpClient.execute(request);
      httpLog.setRespTime(System.currentTimeMillis());
      httpLog.setHttpStatus(httpResponse.getStatusLine().getStatusCode());

      try {
         String resultStr = EntityUtils.toString(httpResponse.getEntity());
         httpLog.setRespBody(resultStr);
      } catch (Exception var19) {
         Exception e = var19;
         httpLog.setErrorMsg(e.getMessage());
      } finally {
         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var18) {
            Exception e3 = var18;
            LCLogger.withException(e3);
         }

      }

      return httpResponse;
   }

   public static HttpResponse doPost(String host, String path, String method, Map<String, String> headers, Map<String, String> querys, byte[] body) throws Exception {
      HttpLog httpLog = new HttpLog();
      HttpPost request = new HttpPost(buildUrl(host, path, querys, httpLog));
      if (body != null && body.length > 0) {
         new Gson();
         String reqParams = httpLog.getReqParams();
         if (StringUtils.isNotBlank(reqParams)) {
            reqParams = reqParams + "==" + body.toString();
         } else {
            reqParams = body.toString();
         }

         httpLog.setReqParams(reqParams);
      }

      Iterator var8 = headers.entrySet().iterator();

      while(var8.hasNext()) {
         Map.Entry<String, String> e = (Map.Entry)var8.next();
         request.addHeader((String)e.getKey(), (String)e.getValue());
      }

      if (body != null) {
         request.setEntity(new ByteArrayEntity(body));
      }

      httpLog.setReqTime(System.currentTimeMillis());
      HttpClient httpClient = wrapClient(host);
      HttpResponse httpResponse = httpClient.execute(request);
      httpLog.setRespTime(System.currentTimeMillis());
      httpLog.setHttpStatus(httpResponse.getStatusLine().getStatusCode());

      try {
         String resultStr = EntityUtils.toString(httpResponse.getEntity());
         httpLog.setRespBody(resultStr);
      } catch (Exception var19) {
         Exception e = var19;
         httpLog.setErrorMsg(e.getMessage());
      } finally {
         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var18) {
            Exception e3 = var18;
            LCLogger.withException(e3);
         }

      }

      return httpResponse;
   }

   public static String sendGet(String url, String param) {
      String result = "";
      BufferedReader in = null;
      HttpLog httpLog = new HttpLog();
      httpLog.setUrl(url);
      httpLog.setReqParams(param);

      try {
         String urlNameString = url + "?" + param;
         URL realUrl = new URL(urlNameString);
         HttpURLConnection connection = (HttpURLConnection)realUrl.openConnection();
         connection.setRequestProperty("accept", "*/*");
         connection.setRequestProperty("connection", "Keep-Alive");
         connection.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
         httpLog.setReqTime(System.currentTimeMillis());
         connection.connect();
         httpLog.setRespTime(System.currentTimeMillis());
         httpLog.setHttpStatus(connection.getResponseCode());
         Map<String, List<String>> map = connection.getHeaderFields();
         Iterator var9 = map.keySet().iterator();

         while(var9.hasNext()) {
            String key = (String)var9.next();
            System.out.println(key + "--->" + map.get(key));
         }

         String line;
         for(in = new BufferedReader(new InputStreamReader(connection.getInputStream())); (line = in.readLine()) != null; result = result + line) {
         }

         httpLog.setRespBody(result);
      } catch (Exception var23) {
         Exception e = var23;
         httpLog.setErrorMsg(e.getMessage());
         logger.error("HttpUtils捕获异常: ", e);
      } finally {
         Exception e3;
         try {
            if (in != null) {
               in.close();
            }
         } catch (Exception var22) {
            e3 = var22;
            logger.error("HttpUtils捕获异常: ", e3);
         }

         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var21) {
            e3 = var21;
            LCLogger.withException(e3);
         }

      }

      return result;
   }

   public static String sendPost(String url, String param) {
      PrintWriter out = null;
      BufferedReader in = null;
      String result = "";
      HttpLog httpLog = new HttpLog();
      httpLog.setUrl(url);
      httpLog.setReqParams(param);
      httpLog.setReqTime(System.currentTimeMillis());

      try {
         URL realUrl = new URL(url);
         HttpURLConnection conn = (HttpURLConnection)realUrl.openConnection();
         conn.setRequestProperty("accept", "*/*");
         conn.setRequestProperty("connection", "Keep-Alive");
         conn.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
         conn.setDoOutput(true);
         conn.setDoInput(true);
         out = new PrintWriter(conn.getOutputStream());
         out.print(param);
         out.flush();

         String line;
         for(in = new BufferedReader(new InputStreamReader(conn.getInputStream())); (line = in.readLine()) != null; result = result + line) {
         }

         httpLog.setHttpStatus(conn.getResponseCode());
         httpLog.setRespBody(result);
         httpLog.setRespTime(System.currentTimeMillis());
      } catch (Exception var21) {
         Exception e = var21;
         httpLog.setErrorMsg(e.getMessage());
         logger.error("HttpUtils捕获异常: ", e);
      } finally {
         try {
            if (out != null) {
               out.close();
            }

            if (in != null) {
               in.close();
            }
         } catch (IOException var20) {
            IOException ex = var20;
            logger.error("HttpUtils捕获异常: ", ex);
         }

         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var19) {
            Exception e3 = var19;
            LCLogger.withException(e3);
         }

      }

      return result;
   }

   public static HttpResponse doPut(String host, String path, String method, Map<String, String> headers, Map<String, String> querys, String body) throws Exception {
      HttpLog httpLog = new HttpLog();
      HttpPut request = new HttpPut(buildUrl(host, path, querys, httpLog));
      if (body != null && StringUtils.isNotBlank(body)) {
         new Gson();
         String reqParams = httpLog.getReqParams();
         if (StringUtils.isNotBlank(reqParams)) {
            reqParams = reqParams + "==" + body;
         } else {
            reqParams = body;
         }

         httpLog.setReqParams(reqParams);
      }

      Iterator var8 = headers.entrySet().iterator();

      while(var8.hasNext()) {
         Map.Entry<String, String> e = (Map.Entry)var8.next();
         request.addHeader((String)e.getKey(), (String)e.getValue());
      }

      if (StringUtils.isNotBlank(body)) {
         request.setEntity(new StringEntity(body, "utf-8"));
      }

      httpLog.setReqTime(System.currentTimeMillis());
      HttpClient httpClient = wrapClient(host);
      HttpResponse httpResponse = httpClient.execute(request);
      httpLog.setRespTime(System.currentTimeMillis());
      httpLog.setHttpStatus(httpResponse.getStatusLine().getStatusCode());

      try {
         String resultStr = EntityUtils.toString(httpResponse.getEntity());
         httpLog.setRespBody(resultStr);
      } catch (Exception var19) {
         Exception e = var19;
         httpLog.setErrorMsg(e.getMessage());
      } finally {
         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var18) {
            Exception e3 = var18;
            LCLogger.withException(e3);
         }

      }

      return httpResponse;
   }

   public static HttpResponse doPut(String host, String path, String method, Map<String, String> headers, Map<String, String> querys, byte[] body) throws Exception {
      HttpLog httpLog = new HttpLog();
      HttpPut request = new HttpPut(buildUrl(host, path, querys, httpLog));
      if (body != null && body.length > 0) {
         new Gson();
         String reqParams = httpLog.getReqParams();
         if (StringUtils.isNotBlank(reqParams)) {
            reqParams = reqParams + "==" + body.toString();
         } else {
            reqParams = body.toString();
         }

         httpLog.setReqParams(reqParams);
      }

      Iterator var8 = headers.entrySet().iterator();

      while(var8.hasNext()) {
         Map.Entry<String, String> e = (Map.Entry)var8.next();
         request.addHeader((String)e.getKey(), (String)e.getValue());
      }

      if (body != null) {
         request.setEntity(new ByteArrayEntity(body));
      }

      httpLog.setReqTime(System.currentTimeMillis());
      HttpClient httpClient = wrapClient(host);
      HttpResponse httpResponse = httpClient.execute(request);
      httpLog.setRespTime(System.currentTimeMillis());
      httpLog.setHttpStatus(httpResponse.getStatusLine().getStatusCode());

      try {
         String resultStr = EntityUtils.toString(httpResponse.getEntity());
         httpLog.setRespBody(resultStr);
      } catch (Exception var19) {
         Exception e = var19;
         httpLog.setErrorMsg(e.getMessage());
      } finally {
         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var18) {
            Exception e3 = var18;
            LCLogger.withException(e3);
         }

      }

      return httpResponse;
   }

   public static HttpResponse doDelete(String host, String path, String method, Map<String, String> headers, Map<String, String> querys) throws Exception {
      HttpClient httpClient = wrapClient(host);
      HttpLog httpLog = new HttpLog();
      HttpDelete request = new HttpDelete(buildUrl(host, path, querys, httpLog));
      Iterator var8 = headers.entrySet().iterator();

      while(var8.hasNext()) {
         Map.Entry<String, String> e = (Map.Entry)var8.next();
         request.addHeader((String)e.getKey(), (String)e.getValue());
      }

      httpLog.setReqTime(System.currentTimeMillis());
      HttpResponse httpResponse = httpClient.execute(request);
      httpLog.setRespTime(System.currentTimeMillis());
      httpLog.setHttpStatus(httpResponse.getStatusLine().getStatusCode());

      try {
         String resultStr = EntityUtils.toString(httpResponse.getEntity());
         httpLog.setRespBody(resultStr);
      } catch (Exception var18) {
         Exception e = var18;
         httpLog.setErrorMsg(e.getMessage());
      } finally {
         try {
            LCLogger.sendHttpLog(httpLog);
         } catch (Exception var17) {
            Exception e3 = var17;
            LCLogger.withException(e3);
         }

      }

      return httpResponse;
   }

   private static String buildUrl(String host, String path, Map<String, String> querys, HttpLog httpLog) throws UnsupportedEncodingException {
      StringBuilder sbUrl = new StringBuilder();
      sbUrl.append(host);
      if (!StringUtils.isBlank(path)) {
         sbUrl.append(path);
      }

      httpLog.setUrl(sbUrl.toString());
      if (null != querys) {
         StringBuilder sbQuery = new StringBuilder();
         Iterator var6 = querys.entrySet().iterator();

         while(var6.hasNext()) {
            Map.Entry<String, String> query = (Map.Entry)var6.next();
            if (0 < sbQuery.length()) {
               sbQuery.append("&");
            }

            if (StringUtils.isBlank((String)query.getKey()) && !StringUtils.isBlank((String)query.getValue())) {
               sbQuery.append((String)query.getValue());
            }

            if (!StringUtils.isBlank((String)query.getKey())) {
               sbQuery.append((String)query.getKey());
               if (!StringUtils.isBlank((String)query.getValue())) {
                  sbQuery.append("=");
                  sbQuery.append(URLEncoder.encode((String)query.getValue(), "utf-8"));
               }
            }
         }

         if (0 < sbQuery.length()) {
            httpLog.setReqParams(sbQuery.toString());
            sbUrl.append("?").append(sbQuery);
         }
      }

      return sbUrl.toString();
   }

   private static HttpClient wrapClient(String host) {
      HttpClient httpClient = new DefaultHttpClient();
      if (host.startsWith("https://")) {
         sslClient(httpClient);
      }

      return httpClient;
   }

   private static void sslClient(HttpClient httpClient) {
      try {
         SSLContext ctx = SSLContext.getInstance("TLSv1.2");
         X509TrustManager tm = new X509TrustManager() {
            public X509Certificate[] getAcceptedIssuers() {
               return null;
            }

            public void checkClientTrusted(X509Certificate[] xcs, String str) throws CertificateException {
               HttpUtils.logger.info("调用checkClientTrusted方法，该方法为空方法。");
            }

            public void checkServerTrusted(X509Certificate[] xcs, String str) throws CertificateException {
               HttpUtils.logger.info("调用checkServerTrusted方法，该方法为空方法。");
            }
         };
         ctx.init((KeyManager[])null, new TrustManager[]{tm}, (SecureRandom)null);
         SSLSocketFactory ssf = new SSLSocketFactory(ctx);
         ssf.setHostnameVerifier(SSLSocketFactory.ALLOW_ALL_HOSTNAME_VERIFIER);
         ClientConnectionManager ccm = httpClient.getConnectionManager();
         SchemeRegistry registry = ccm.getSchemeRegistry();
         registry.register(new Scheme("https", 443, ssf));
      } catch (KeyManagementException var6) {
         KeyManagementException ex = var6;
         throw new RuntimeException(ex);
      } catch (NoSuchAlgorithmException var7) {
         NoSuchAlgorithmException ex = var7;
         throw new RuntimeException(ex);
      }
   }

   public static Map<String, String> queryLogistics(String logisticsNo, String logisticsCompany) {
      Map<String, String> map = new HashMap();
      String host = "http://ali-deliver.showapi.com";
      String path = "/showapi_expInfo";
      String method = "GET";
      Map<String, String> headers = new HashMap();
      headers.put("Authorization", "APPCODE 561bcd046bdf4be19ca6c8b219fcce55");
      Map<String, String> querys = new HashMap();
      querys.put("com", "auto");
      if (StringUtils.isNull(logisticsNo)) {
         map.put("success", "false");
         map.put("result", "物流单号为空，无法查询物流信息！");
         return map;
      } else {
         querys.put("nu", logisticsNo);

         try {
            HttpResponse response = doGet(host, path, method, headers, querys);
            String result = EntityUtils.toString(response.getEntity());
            map.put("success", "true");
            map.put("result", result);
            return map;
         } catch (Exception var10) {
            Exception e = var10;
            logger.error("HttpUtils捕获异常: ", e);
            map.put("success", "false");
            map.put("result", e.toString());
            return map;
         }
      }
   }

   public static Map<String, Double> getLngAndLat(String address) throws Exception {
      Map<String, Double> map = new HashMap();
      String url = "http://api.map.baidu.com/geocoder/v2/?address=" + address + "&output=json&ak=X19IbB6EWVWpGrNBZuyUI9LpCi2aXMXr";
      String json = loadJSON(url);
      JSONObject obj = JSONObject.parseObject(json);
      System.out.println(obj.toString());
      if ("0".equals(obj.get("status").toString())) {
         double lng = obj.getJSONObject("result").getJSONObject("location").getDouble("lng");
         double lat = obj.getJSONObject("result").getJSONObject("location").getDouble("lat");
         map.put("longtitude", lng);
         map.put("latitude", lat);
         System.out.println("经度：" + lng + "，纬度：" + lat);
      } else {
         System.out.println("未找到相匹配的经纬度！");
      }

      return map;
   }

   public static String loadJSON(String url) {
      StringBuilder json = new StringBuilder();

      try {
         URL oracle = new URL(url);
         URLConnection yc = oracle.openConnection();
         BufferedReader in = new BufferedReader(new InputStreamReader(yc.getInputStream()));
         String inputLine = null;

         while((inputLine = in.readLine()) != null) {
            json.append(inputLine);
         }

         in.close();
      } catch (MalformedURLException var6) {
      } catch (IOException var7) {
      }

      return json.toString();
   }

   public static void main(String[] args) {
      try {
         Map<String, Double> map = getLngAndLat("广州市番禺区天安科技园");
         System.out.println("1:" + map.get("longtitude"));
         System.out.println("2:" + map.get("latitude"));
      } catch (Exception var2) {
         Exception e = var2;
         logger.error("HttpUtils捕获异常: ", e);
      }

   }
}
